@@ -7,6 +7,7 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
+    "Can not add feed: Unable to parse feed" : "Kan inte lägga till flöde: Går inte att läsa flöde",
     "Can not add feed: Exists already" : "Kan inte lägga till: flödet existerar redan",
     "Articles without feed" : "Artiklar utan flöde",
     "Can not add folder: Exists already" : "Kan inte lägga till: mappen existerar redan",
@@ -23,7 +24,7 @@ OC.L10N.register(
     "Maximum feed page size" : "Maximum storlek på flödessidan",
     "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximum storlek på flödet i bytes. Om RSS/Atom sidan är större än detta värde, kommer uppdateringen att avbrytas.",
     "Feed fetcher timeout" : "Timeout för flödes-hämtare",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximalt antal sekunder att vänta på att RSS/Atom flödet skall ladda. Om det tar längre tid avbryts uppdateringen.",
+    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
     "Explore Service URL" : "Utforska tjänstwebbadress",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Om angiven kommer denna tjänsts webbadress bli förfrågad om visning av flöden i flödet för utforskarsektionen. För att falla tillbaks på den inbyggda utforskar tjänsten, lämna detta inmatningsfält tomt\n\nOm detta anges kommer den här tjänstens webbadress att bli förfrågad av visning av flöden i avsnittet utforska flödet. För att återgå till den inbyggda utforskartjänsten, lämna det här inmatningsfältet tomt",
     "For more information check the wiki" : "För mer information, se wiki.",
@@ -58,10 +59,10 @@ OC.L10N.register(
     "Open article in new tab" : "Öppna artikeln i ny flik",
     "Toggle expand article in compact view" : "Aktivera för att expandera artikeln i kompakt vy",
     "Refresh" : "Uppdatera",
-    "Load next feed" : "Ladda nästkommande flöde",
-    "Load previous feed" : "Ladda föregående flöde",
-    "Load next folder" : "Ladda nästkommande mapp",
-    "Load previous folder" : "Ladda föregående mapp",
+    "Load next feed" : "Läs in nästkommande flöde",
+    "Load previous feed" : "Läs in föregående flöde",
+    "Load next folder" : "Läs in nästkommande mapp",
+    "Load previous folder" : "Läs in föregående mapp",
     "Scroll to active navigation entry" : "Skrolla till aktiv navigations-post",
     "Focus search field" : "Fokuserat sökfält",
     "Mark current article's feed/folder read" : "Markera nuvarande artikels flöde/mapp som läst",
